texlive[52847] Build/source/texk: sync

commits+karl at tug.org commits+karl at tug.org
Sun Nov 17 23:42:51 CET 2019


Revision: 52847
          http://tug.org/svn/texlive?view=revision&revision=52847
Author:   karl
Date:     2019-11-17 23:42:51 +0100 (Sun, 17 Nov 2019)
Log Message:
-----------
sync

Modified Paths:
--------------
    trunk/Build/source/texk/dvipdfm-x/data/dvipdfmx.cfg
    trunk/Build/source/texk/tests/TeXLive/TLUtils.pm
    trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl

Modified: trunk/Build/source/texk/dvipdfm-x/data/dvipdfmx.cfg
===================================================================
--- trunk/Build/source/texk/dvipdfm-x/data/dvipdfmx.cfg	2019-11-17 22:38:43 UTC (rev 52846)
+++ trunk/Build/source/texk/dvipdfm-x/data/dvipdfmx.cfg	2019-11-17 22:42:51 UTC (rev 52847)
@@ -156,7 +156,7 @@
 %% kpsewhich -progname=dvipdfmx -format='other text files' dvipdfmx.cfg
 %% and control which one is found by setting DVIPDFMXINPUTS.
 %%
-D  "rungs -q -dNOPAUSE -dBATCH -dEPSCrop -sPAPERSIZE=a0 -sDEVICE=pdfwrite -dCompatibilityLevel=%v -dAutoFilterGrayImages=false -dGrayImageFilter=/FlateEncode -dAutoFilterColorImages=false -dColorImageFilter=/FlateEncode -dAutoRotatePages=/None -sOutputFile='%o' '%i' -c quit"
+D  "rungs -q -dDELAYSAFER -dNOPAUSE -dBATCH -dEPSCrop -sPAPERSIZE=a0 -sDEVICE=pdfwrite -dCompatibilityLevel=%v -dAutoFilterGrayImages=false -dGrayImageFilter=/FlateEncode -dAutoFilterColorImages=false -dColorImageFilter=/FlateEncode -dAutoRotatePages=/None -sOutputFile='%o' '%i' -c quit"
 
 % other random ps converters people have experimented with.
 %D "/usr/local/bin/ps2pdf -dEPSCrop '%i' '%o'"

Modified: trunk/Build/source/texk/tests/TeXLive/TLUtils.pm
===================================================================
--- trunk/Build/source/texk/tests/TeXLive/TLUtils.pm	2019-11-17 22:38:43 UTC (rev 52846)
+++ trunk/Build/source/texk/tests/TeXLive/TLUtils.pm	2019-11-17 22:42:51 UTC (rev 52847)
@@ -5,7 +5,7 @@
 
 package TeXLive::TLUtils;
 
-my $svnrev = '$Revision: 52706 $';
+my $svnrev = '$Revision: 52815 $';
 my $_modulerevision = ($svnrev =~ m/: ([0-9]+) /) ? $1 : "unknown";
 sub module_revision { return $_modulerevision; }
 
@@ -2182,7 +2182,7 @@
     if ($tlchecksum ne $checksum) {
       tlwarn("TLUtils::check_file: checksums differ for $xzfile:\n");
       tlwarn("TLUtils::check_file:   tlchecksum=$tlchecksum, arg=$checksum\n");
-      (undef,$check_file_tmpdir) = File::temp::tempdir("tlcheckfileXXXXXXXX");
+      (undef,$check_file_tmpdir) = File::Temp::tempdir("tlcheckfileXXXXXXXX");
       tlwarn("TLUtils::check_file:   removing $xzfile, "
              . "but saving copy in $check_file_tmpdir\n");
       copy($xzfile, $check_file_tmpdir);
@@ -2202,7 +2202,7 @@
       if (!defined($check_file_tmpdir)) {
         # the tmpdir should always be undefined, since we shouldn't get
         # here if the checksums failed, but test anyway.
-        $check_file_tmpdir = File::temp::tempdir("tlcheckfileXXXXXXXX");
+        $check_file_tmpdir = File::Temp::tempdir("tlcheckfileXXXXXXXX");
         tlwarn("TLUtils::check_file:  saving copy in $check_file_tmpdir\n");
         copy($xzfile, $check_file_tmpdir);
       }

Modified: trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl	2019-11-17 22:38:43 UTC (rev 52846)
+++ trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl	2019-11-17 22:42:51 UTC (rev 52847)
@@ -1,12 +1,12 @@
 #!/usr/bin/env perl
-# $Id: tlmgr.pl 52799 2019-11-15 18:38:19Z karl $
+# $Id: tlmgr.pl 52830 2019-11-17 17:05:39Z karl $
 #
 # Copyright 2008-2019 Norbert Preining
 # This file is licensed under the GNU General Public License version 2
 # or any later version.
 
-my $svnrev = '$Revision: 52799 $';
-my $datrev = '$Date: 2019-11-15 19:38:19 +0100 (Fri, 15 Nov 2019) $';
+my $svnrev = '$Revision: 52830 $';
+my $datrev = '$Date: 2019-11-17 18:05:39 +0100 (Sun, 17 Nov 2019) $';
 my $tlmgrrevision;
 my $tlmgrversion;
 my $prg;
@@ -5686,7 +5686,7 @@
       # luahbtex is special until we build it everywhere for TL'20.
       # 
       # We do not want to have error messages here, so we do the following:
       # * if tlpkg/tlpsrc/luatex.tlpsrc is available, then load it
       #   and filter away those archs that are excluded with f/!...
       # * similarly for the other partial-support engines; too much
       #   trouble to reverse-map to package names, so just hardwire;
@@ -5694,9 +5694,9 @@
       #   the development tree) we just ignore it completely.
       my $pkg;
       if ($engine eq "luajittex") {
-        $pkg = "luatex";
+        $pkg = "luajittex";
       } elsif ($engine eq "luahbtex") {
-        $pkg = "latex-bin-dev";
+        $pkg = "luahbtex";
       } elsif ($engine eq "mfluajit") {
         $pkg = "mflua";
       } else {
@@ -9076,7 +9076,7 @@
   tlmgr remove --force foobar
 
 Again, since packages are sometimes renamed or replaced, using this
-option is not recommended.
+option is not ecommended.
 
 =item B<--reinstall-forcibly-removed>
 
@@ -9952,7 +9952,7 @@
 distribution (L<https://tug.org/texlive>) and both are licensed under the
 GNU General Public License Version 2 or later.
 
-$Id: tlmgr.pl 52799 2019-11-15 18:38:19Z karl $
+$Id: tlmgr.pl 52830 2019-11-17 17:05:39Z karl $
 =cut
 
 # test HTML version: pod2html --cachedir=/tmp tlmgr.pl >/tmp/tlmgr.html
@@ -5686,7 +5686,7 @@
       # 
       # We do not want to have error messages here, so we do the following:
-      # * if tlpkg/tlpsrc/luatex.tlpsrc is available, then load it
+      # * if tlpkg/tlpsrc/luajittex.tlpsrc is available, then load it
       #   and filter away those archs that are excluded with f/!...
       # * similarly for the other partial-support engines; too much



More information about the tex-live-commits mailing list